@@ -6,11 +6,41 @@ import os
 from rq import Queue, Worker
 from redis import Redis
 
+
+default_cfg = """
+[GENERAL]
+testmode = False
+cores = 1 
+processing_mode = local
+[PATHS]
+patientpath = ./Patients/
+panelspath = ./Panels/
+reportspath = ./Reports/
+resultspath = ./Results/
+pipelinespath = ./Pipelines/
+referencespath = ./References/
+testpath = ./test/
+dbpath = ./VariantsDB/variantsDB.csv
+tmppath = ./tmp/
+binpath = ./bin/
+
+[OUTPUT]
+columnsorder = GENE_NAME, AMINOCHANGE, HGVS.P, HGVS.C, RSID, IMPACT, EFFECT, FEATURE_ID, VARDB_FREQ, ALLELE_FREQ, 1000GP3_AF, 1000GP3_AFR_AF,
+            1000GP3_AMR_AF, 1000GP3_EAS_AF, 1000GP3_EUR_AF, 1000GP3_SAS_AF,ESP6500_MAF_EA, ESP6500_MAF_AA,
+            ESP6500_MAF_ALL, CLINVAR_CLNSIG, CLINVAR_CLNDSDB,CLINVAR_CLNDSDBID, CLINVAR_CLNDBN, CLINVAR_CLNREVSTAT,
+            CLINVAR_CLNACC, POLYPHEN_PRED,POLYPHEN_SCORE, VENN, ZIGOSITY, CHROM, POS, REF, ALT, VARTYPE
+"""
+
+
 # config parsing from here on, parses paths and things from config.ini
+cfgPath = os.path.join(os.path.dirname(os.path.realpath(__file__)), "config.ini")
 cfg = configparser.ConfigParser()
-cfgPath = os.path.join(os.path.dirname(os.path.realpath(__file__)),
-                       "config.ini")
-cfg.read(cfgPath)
+if os.path.exists(cfgPath):
+    cfg.read(cfgPath)
+else:
+    cfg.read_string(default_cfg)
+    with open(cfgPath, "w") as cfgfile:
+        cfg.write(cfgfile)
 
 rootDir = os.path.dirname(os.path.abspath(__file__))
 
@@ -39,10 +69,8 @@ if cfg.has_option("REDIS", "host"):
     redis_conn = Redis(cfg["REDIS"]["host"])
 else:
     redis_conn = Redis()
-short_queue = Queue(name="short_queue", default_timeout=-1,
-                    connection=redis_conn)
-long_queue = Queue(name="long_queue", default_timeout=-1,
-                   connection=redis_conn)
+short_queue = Queue(name="short_queue", default_timeout=-1, connection=redis_conn)
+long_queue = Queue(name="long_queue", default_timeout=-1, connection=redis_conn)
 
 
 def setConfig(section, key, value):
@@ -55,8 +83,7 @@ def setConfig(section, key, value):
                 "Key error: Requested %s key is not present in config file" % key
             )
     else:
-        logging.error(
-            "Section error: Section %s not present in config file" % section)
+        logging.error("Section error: Section %s not present in config file" % section)
     with open(cfgPath, "w") as cfgfile:
         cfg.write(cfgfile)
 
@@ -144,3 +171,4 @@ def setup_logging():
     }
 
     logging.config.dictConfig(logCfg)
+
